"use strict";
var P = require("bluebird");
var http_platform_client_1 = require("./client/http-platform-client");
var stream_platform_client_1 = require("./client/stream-platform-client");
var messaging_platform_client_1 = require("./client/messaging-platform-client");
(function (PlatformProtocols) {
    PlatformProtocols[PlatformProtocols["HTTP"] = 0] = "HTTP";
    PlatformProtocols[PlatformProtocols["STREAM"] = 1] = "STREAM";
    PlatformProtocols[PlatformProtocols["MESSAGING"] = 2] = "MESSAGING";
})(exports.PlatformProtocols || (exports.PlatformProtocols = {}));
var PlatformProtocols = exports.PlatformProtocols;
var PlatformLocator = (function () {
    function PlatformLocator() {
    }
    /**
     * Primary platform facade. Connect will establish a connection to the platform and return
     * a platform instance to perform operations.
     *
     * @param cfg PlatformLocatorOptions instance
     *
     * @returns {Promise<Platform>|Promise}
     */
    PlatformLocator.connect = function (cfg) {
        cfg = cfg || { protocol: PlatformProtocols.STREAM, secure: false, host: 'localhost', port: 25025, version: 1 };
        return new P(function (resolve, reject) {
            var impl = null;
            switch (cfg.protocol) {
                case PlatformProtocols.HTTP:
                    impl = new http_platform_client_1.HttpPlatformClient(cfg.host, cfg.port, { secure: cfg.secure, version: cfg.version });
                    break;
                case PlatformProtocols.STREAM:
                    impl = new stream_platform_client_1.StreamPlatformClient(cfg.host, cfg.port, { secure: cfg.secure, version: cfg.version });
                    break;
                case PlatformProtocols.MESSAGING:
                    impl = new messaging_platform_client_1.MessagingPlatformClient(cfg.host, cfg.port, { secure: cfg.secure, version: cfg.version });
                    break;
            }
            resolve(impl);
        });
    };
    return PlatformLocator;
}());
exports.PlatformLocator = PlatformLocator;

//# sourceMappingURL=platform-locator.js.map
