"use strict";
var joi = require("joi");
var guid_1 = require("./guid");
/**
 * Schema describes a data structure
 */
var Schema = (function () {
    function Schema(id, version) {
        this.id = id || guid_1.Guid.newGuid();
        this.version = version || 1;
        this.schema = joi.object();
    }
    Schema.prototype.getId = function () {
        return this.id;
    };
    Schema.prototype.getUrn = function () {
        return "urn:" + this.id + ":" + this.version;
    };
    /**
     * Check if the provided object comply with this schema
     * @param object The object to validate
     * @return Promise resolved on the
     */
    Schema.prototype.validate = function (object) {
        return joi.validate(object, this.schema);
    };
    /**
     * Configure the Joi object schema for this schema.
     * @param object
     * @returns {joi.ObjectSchema} The joi schema directly to add support for chaining syntax
     */
    Schema.prototype.keys = function (object) {
        this.schema = this.schema.keys(object);
        return this.schema;
    };
    /**
     * Transform this object into a complying schema instance.
     * @param object
     */
    Schema.prototype.normalize = function (object) {
        return joi.validate(object, this.schema, { convert: true, allowUnknown: true, stripUnknown: true });
    };
    Schema.Types = joi;
    return Schema;
}());
exports.Schema = Schema;

//# sourceMappingURL=schema.js.map
